@@ -15,8 +15,8 @@
 
 import copy
 
-from ceilometerclient.openstack.common.apiclient import client
-from ceilometerclient.openstack.common.apiclient import fake_client
+from ceilometerclient.apiclient import client
+from ceilometerclient.apiclient import fake_client
 from ceilometerclient.tests.unit import utils
 import ceilometerclient.v2.samples
 
@@ -54,7 +54,9 @@ GET_SAMPLE = {
 }
 
 METER_URL = '/v2/meters/instance'
+METER_URL_DIRECT = '/v2/meters/instance?direct=True'
 SECOND_METER_URL = '/v2/meters/image'
+SECOND_METER_URL_DIRECT = '/v2/meters/image?direct=True'
 SAMPLE_URL = '/v2/samples'
 QUERIES = ('q.field=resource_id&q.field=source&q.op=&q.op='
            '&q.type=&q.type=&q.value=foo&q.value=bar')
@@ -71,12 +73,24 @@ OLD_SAMPLE_FIXTURES = {
             [CREATE_SAMPLE],
         ),
     },
+    METER_URL_DIRECT: {
+        'POST': (
+            {},
+            [CREATE_SAMPLE],
+        )
+    },
     SECOND_METER_URL: {
         'POST': (
             {},
             [CREATE_LIST_SAMPLE] * 10,
         ),
     },
+    SECOND_METER_URL_DIRECT: {
+        'POST': (
+            {},
+            [CREATE_LIST_SAMPLE] * 10,
+        )
+    },
     '%s?%s' % (METER_URL, QUERIES): {
         'GET': (
             {},
@@ -133,8 +147,8 @@ class OldSampleManagerTest(utils.BaseTestCase):
             'GET', '/v2/meters/instance'
         ]
         self.http_client.assert_called(*expect)
-        self.assertEqual(len(samples), 1)
-        self.assertEqual(samples[0].resource_id, 'resource-id')
+        self.assertEqual(1, len(samples))
+        self.assertEqual('resource-id', samples[0].resource_id)
 
     def test_list_by_meter_name_extended(self):
         samples = list(self.mgr.list(meter_name='instance',
@@ -146,7 +160,7 @@ class OldSampleManagerTest(utils.BaseTestCase):
                                      ]))
         expect = ['GET', '%s?%s' % (METER_URL, QUERIES)]
         self.http_client.assert_called(*expect)
-        self.assertEqual(len(samples), 0)
+        self.assertEqual(0, len(samples))
 
     def test_create(self):
         sample = self.mgr.create(**CREATE_SAMPLE)
@@ -156,6 +170,14 @@ class OldSampleManagerTest(utils.BaseTestCase):
         self.http_client.assert_called(*expect, body=[CREATE_SAMPLE])
         self.assertIsNotNone(sample)
 
+    def test_create_directly(self):
+        sample = self.mgr.create(direct=True, **CREATE_SAMPLE)
+        expect = [
+            'POST', '/v2/meters/instance?direct=True'
+        ]
+        self.http_client.assert_called(*expect, body=[CREATE_SAMPLE])
+        self.assertIsNotNone(sample)
+
     def test_create_list(self):
         test_samples = [CREATE_LIST_SAMPLE] * 10
         samples = self.mgr.create_list(test_samples)
@@ -165,11 +187,20 @@ class OldSampleManagerTest(utils.BaseTestCase):
         self.http_client.assert_called(*expect, body=test_samples)
         self.assertEqual(10, len(samples))
 
+    def test_create_list_directly(self):
+        test_samples = [CREATE_LIST_SAMPLE] * 10
+        samples = self.mgr.create_list(test_samples, direct=True)
+        expect = [
+            'POST', '/v2/meters/image?direct=True'
+        ]
+        self.http_client.assert_called(*expect, body=test_samples)
+        self.assertEqual(10, len(samples))
+
     def test_limit(self):
         samples = list(self.mgr.list(meter_name='instance', limit=1))
         expect = ['GET', '/v2/meters/instance?limit=1']
         self.http_client.assert_called(*expect)
-        self.assertEqual(len(samples), 1)
+        self.assertEqual(1, len(samples))
 
 
 class SampleManagerTest(utils.BaseTestCase):
